@@ -1,4 +1,4 @@
-from api.bag import adres_uitgebreid
+from api.bag import _adres_uitgebreid
 
 def add_one(number):
     return number + 1
@@ -6,4 +6,4 @@ def add_one(number):
 if __name__ == "__main__":
     x = add_one(2)
     print(x)
-    adres_uitgebreid()
\ No newline at end of file
+    _adres_uitgebreid()
\ No newline at end of file
